# PyBalance

The `pybalance` library implements several routines for optimizing the balance
between non-random populations. In observational studies, this matching process
is a key step towards minimizing the potential effects of confounding
covariates. The official documentation is hosted [here](https://bayer-group.github.io/pybalance/).
